package com.zehong.web.controller.userRelation;

import java.util.List;

import com.zehong.common.core.domain.entity.SysUser;
import com.zehong.common.core.exception.BusinessException;
import com.zehong.common.utils.SecurityUtils;
import com.zehong.common.utils.StringUtils;
import com.zehong.system.service.ISysUserService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TUserRelation;
import com.zehong.system.service.ITUserRelationService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 用户关联Controller
 * 
 * @author zehong
 * @date 2023-07-11
 */
@RestController
@RequestMapping("/user/relation")
public class TUserRelationController extends BaseController
{
    @Autowired
    private ITUserRelationService tUserRelationService;

    @Autowired
    private ISysUserService sysUserService;

    /**
     * 查询用户关联列表
     */
    //@PreAuthorize("@ss.hasPermi('system:relation:list')")
    @GetMapping("/list")
    public TableDataInfo list(TUserRelation tUserRelation)
    {
        startPage();
        List<TUserRelation> list = tUserRelationService.selectTUserRelationList(tUserRelation);
        return getDataTable(list);
    }

    /**
     * 导出用户关联列表
     */
    //@PreAuthorize("@ss.hasPermi('system:relation:export')")
    @Log(title = "用户关联", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TUserRelation tUserRelation)
    {
        List<TUserRelation> list = tUserRelationService.selectTUserRelationList(tUserRelation);
        ExcelUtil<TUserRelation> util = new ExcelUtil<TUserRelation>(TUserRelation.class);
        return util.exportExcel(list, "用户关联数据");
    }

    /**
     * 获取用户关联详细信息
     */
   // @PreAuthorize("@ss.hasPermi('system:relation:query')")
    @GetMapping(value = "/{relationId}")
    public AjaxResult getInfo(@PathVariable("relationId") Long relationId)
    {
        return AjaxResult.success(tUserRelationService.selectTUserRelationById(relationId));
    }

    /**
     * 新增用户关联
     */
    //@PreAuthorize("@ss.hasPermi('system:relation:add')")
    @Log(title = "用户关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TUserRelation tUserRelation)
    {
        validateRelationUser(tUserRelation);
        return toAjax(tUserRelationService.insertTUserRelation(tUserRelation));
    }

    /**
     * 校验关联信息
     * @param tUserRelation 关联信息
     */
    private void validateRelationUser(TUserRelation tUserRelation){
        SysUser sysUser = sysUserService.selectUserByUserName(tUserRelation.getAccount());
        if (StringUtils.isNull(sysUser)){
            throw new UsernameNotFoundException("登录用户：" + tUserRelation.getAccount() + " 不存在");
        }
        boolean isPass = SecurityUtils.matchesPassword(tUserRelation.getPassword(),sysUser.getPassword());
        if(!isPass){
            throw new BusinessException("密码错误");
        }
        TUserRelation relation = new TUserRelation();
        relation.setRelationUserId(sysUser.getUserId());
        relation.setUserId(tUserRelation.getUserId());
        List<TUserRelation> relations = tUserRelationService.selectTUserRelationList(relation);
        if(!CollectionUtils.isEmpty(relations)){
            throw new BusinessException("关联账户已存在！");
        }
        if(tUserRelation.getUserId().equals(sysUser.getUserId())){
            throw new BusinessException("不能关联当前账户");
        }
        tUserRelation.setRelationUserId(sysUser.getUserId());
    }

    /**
     * 修改用户关联
     */
    //@PreAuthorize("@ss.hasPermi('system:relation:edit')")
    @Log(title = "用户关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TUserRelation tUserRelation)
    {
        return toAjax(tUserRelationService.updateTUserRelation(tUserRelation));
    }

    /**
     * 删除用户关联
     */
    //@PreAuthorize("@ss.hasPermi('system:relation:remove')")
    @Log(title = "用户关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{relationIds}")
    public AjaxResult remove(@PathVariable Long[] relationIds)
    {
        return toAjax(tUserRelationService.deleteTUserRelationByIds(relationIds));
    }
}
